@@ -8,14 +8,14 @@ knitr::opts_chunk$set(
 library(refseqR)
 
 ## -----------------------------------------------------------------------------
-gene_symbol <- c("LOC101512347")
-transcript <- refseq_fromGene(gene_symbol, sequence = "XM", retries = 3)
-protein <- refseq_fromGene(gene_symbol, sequence = "XP", retries = 3)
+GeneID <- c("LOC101512347")
+transcript <- refseq_fromGene(GeneID, sequence = "transcript", retries = 4)
+protein <- refseq_fromGene(GeneID, sequence = "protein", retries = 4)
 
 ## -----------------------------------------------------------------------------
-gene_symbol <- c("LOC105852298")
-transcript <- refseq_fromGene(gene_symbol, sequence = "XM", retries = 3)
-protein <- refseq_fromGene(gene_symbol, sequence = "XP", retries = 3)
+GeneID <- c("LOC105852298")
+transcript <- refseq_fromGene(GeneID, sequence = "transcript", retries = 4)
+protein    <- refseq_fromGene(GeneID, sequence = "protein", retries = 4)
 
 ## -----------------------------------------------------------------------------
 id <- c("LOC101512347")
@@ -26,40 +26,40 @@ mrna_gb <- rentrez::entrez_fetch(db= 'nuccore', id = "XM_004487701", rettype = '
 strsplit(mrna_gb, "\n")[[1]][1:30]
 
 ## ---- eval = F----------------------------------------------------------------
-#  xm = c("XM_004487701", "XM_004488493", "XM_004501904")
+#  transcript = c("XM_004487701", "XM_004488493", "XM_004501904")
 #  feat = c("caption", "moltype", "sourcedb", "slen", "title")
-#  refseq_fromXM(xm ,feat)
+#  refseq_mRNAfeat(transcript ,feat)
 
 ## -----------------------------------------------------------------------------
-xm <- "XM_004487701"
-refseq_XPfromXM(xm)
+transcript <- "XM_004487701"
+refseq_mRNA2protein(transcript)
 
 ## -----------------------------------------------------------------------------
-refseq_CDScoords(xm)
-refseq_CDSseq(xm)
+refseq_CDScoords(transcript)
+refseq_CDSseq(transcript)
 
 ## -----------------------------------------------------------------------------
-mrna_fasta = rentrez::entrez_fetch(db="nuccore", id=xm, rettype="fasta")
+mrna_fasta = rentrez::entrez_fetch(db="nuccore", id=transcript, rettype="fasta")
 # take a look at the first 500 chars. 
 cat(strwrap(substr(mrna_fasta, 1, 500)), sep="\n")
 
 ## -----------------------------------------------------------------------------
-substr(toString(refseq_CDSseq(xm)), 1, 60)
+substr(toString(refseq_CDSseq(transcript)), 1, 60)
 
 ## -----------------------------------------------------------------------------
 id <- "XM_004487701"
 refseq_description(id)
 
 ## -----------------------------------------------------------------------------
-xp <- "XP_020244413"
-refseq_XMfromXP(xp)
+protein <- "XP_020244413"
+refseq_protein2mRNA(protein)
 
 ## -----------------------------------------------------------------------------
-refseq_XPlength(xp, retries = 3)
-refseq_mol_wt(xp)
+refseq_AA_length(protein, retries = 4)
+refseq_AA_mol_wt(protein)
 
 ## -----------------------------------------------------------------------------
-refseq_AAseq(xp)
+refseq_AAseq(protein)
 
 ## -----------------------------------------------------------------------------
 id <- "XP_020244413"
